import javax.bluetooth.*;


/**
 * @author Michel Deriaz
 */ 
public class BTServices implements Runnable, DiscoveryListener {
  RemoteDevice remoteDevice;
  ServiceRecord[] serviceRecord;
  boolean isSearching;


  public BTServices(RemoteDevice remoteDevice) {
    this.remoteDevice = remoteDevice;
    isSearching = true;
    Thread runner = new Thread(this);
    runner.start();
  }

 
  public ServiceRecord[] getServiceRecord() {
    if (serviceRecord == null) return new ServiceRecord[0];
    return serviceRecord;
  }
  
  
  public int getNbServices() {
    if (serviceRecord == null) return 0;
    return serviceRecord.length;
  }
  

  public String getUrl(int i) {
    if (serviceRecord == null) return null;
    if (serviceRecord.length <= i) return null;
    return serviceRecord[i].getConnectionURL(ServiceRecord.NOAUTHENTICATE_NOENCRYPT, false);
  }    

      
  public void waitUntilFinished() {
    while (isSearching) Thread.yield();
  }


  public void run() {
    try {
      DiscoveryAgent discoveryAgent = LocalDevice.getLocalDevice().getDiscoveryAgent();
      discoveryAgent.searchServices(null, new UUID[]{new UUID(0x1101)}, remoteDevice, this);
    }
    catch (Exception e) {
      System.out.println("BTServices.run: " + e);
    }
  }
  

  public void servicesDiscovered(int transID, ServiceRecord[] servRecord) {
    serviceRecord = servRecord;
  }


  public void serviceSearchCompleted(int transID, int respCode) {
    isSearching = false;
  }


  public void deviceDiscovered(RemoteDevice btDevice, DeviceClass cod) {}
  public void inquiryCompleted(int discType) {}
}