import javax.microedition.lcdui.*;
import java.util.*;
import javax.bluetooth.*;


/**
 * @author Michel Deriaz
 */ 
public class MainForm extends Form implements Runnable, CommandListener {
  BTExplorer btExplorer;
  StringItem si;
  Command cmdUpdate, cmdExit;
 
  
  public MainForm(BTExplorer btExplorer) {
    super(null);
    this.btExplorer = btExplorer;
    si = new StringItem("Results", "");
    append(si);
    cmdUpdate = new Command("Update", Command.ITEM, 0);
    addCommand(cmdUpdate);
    cmdExit = new Command("Exit", Command.EXIT, 0);
    addCommand(cmdExit);
    setCommandListener(this);
    start();
  }
  

  public void start() {
    si.setText("\n\n");
    Thread runner = new Thread(this);
    runner.start();
  }
  
   
  public void commandAction(Command c, Displayable s) {
    if (c.equals(cmdUpdate)) start();
    if (c.equals(cmdExit)) btExplorer.destroyApp(true);
  }
  
  
  public void run() {
    try {
      btExplorer.setCurrent(new Form("Searching..."));
      BTDevices btDevices = new BTDevices();
      btDevices.waitUntilFinished();
      Vector devices = btDevices.getDevices();
      Vector names = btDevices.getFriendlyNames();
      Vector deviceClasses = btDevices.getDeviceClasses();
      for (int i = 0; i < names.size(); i++) {
        try {
          siAppend((String)names.elementAt(i));
          DeviceClass dc = (DeviceClass)deviceClasses.elementAt(i);
          siAppend("Major device class = " +  dc.getMajorDeviceClass());
          siAppend("Minor device class = " +  dc.getMinorDeviceClass());
          siAppend("Services classes = " +  dc.getServiceClasses());
          RemoteDevice rd = (RemoteDevice)devices.elementAt(i);
          siAppend("Address: " + rd.getBluetoothAddress());
          siAppend("Authenticated: " + rd.isAuthenticated());
          siAppend("Encrypted: " + rd.isEncrypted());
          siAppend("Trusted: " + rd.isTrustedDevice());
          BTServices btServices = new BTServices(rd);
          btServices.waitUntilFinished();
          ServiceRecord[] serviceRecord = btServices.getServiceRecord();
          siAppend("Nb services = " + serviceRecord.length);
          for (int j = 0; j < serviceRecord.length; j++) {
            ServiceRecord sr = serviceRecord[j];
            siAppend("" + (j+1) + ") URL = " + sr.getConnectionURL(ServiceRecord.NOAUTHENTICATE_NOENCRYPT, false));
            int[] id = sr.getAttributeIDs();
            String attributeID = "";
            for (int k = 0; k < id.length; k++) {
              attributeID += id[k];
              if (k != id.length - 1) attributeID += ",";
            }
            if (id.length == 0) attributeID = "No attribute ID";
            siAppend("" + (j+1) + ") Attribute ID = " + attributeID);
          }
          siAppend("\n");
        }
        catch (Throwable t) {
          siAppend("UNEXPECTED ERROR: " + t);
          siAppend("\n");
        }
      }
    }
    catch (Throwable t) {
      siAppend("UNEXPECTED ERROR DURING INITIALISATION: " + t);
      siAppend("\n");
    }
    finally {    
      btExplorer.setCurrent(this);
    }
  }
  
  
  private void siAppend(String s) {
    si.setText(si.getText() + s + "\n");
  }
}